@@ -92,7 +92,7 @@ class Webapp():
         """
         self.__webapp.ChangeEnvironment(date, group, branch, module)
 
-    def CheckResult(self, field, user_value, grid=False, line=1, grid_number=1, name_attr=False):
+    def CheckResult(self, field, user_value, grid=False, line=1, grid_number=1, name_attr=False, input_field=True, direction=None):
         """
         Checks if a field has the value the user expects.
 
@@ -108,6 +108,10 @@ class Webapp():
         :type grid_number: int
         :param name_attr: Boolean if search by Name attribute must be forced. - **Default:** False
         :type name_attr: bool
+        :param input_field: False if the desired field is not an input type .
+        :type bool
+        :param direction: Desired direction to search for the element, currently accepts right and down.
+        :type str
 
         Usage:
 
@@ -121,8 +125,13 @@ class Webapp():
         >>> # Calling method to check a field that is on the second grid of the screen:
         >>> oHelper.CheckResult("Order", "000001", grid=True, line=1, grid_number=2)
         >>> oHelper.LoadGrid()
+        >>> #-----------------------------------------
+        >>> # Call method to check a field value that is not an input field and is on the right:
+        >>> oHelper.CheckResult("Saldo Titulo", "100.000,00", input_field=False, direction='right')
+        >>> oHelper.LoadGrid()
+
         """
-        self.__webapp.CheckResult(field, user_value, grid, line, grid_number, name_attr)
+        self.__webapp.CheckResult(field, user_value, grid, line, grid_number, name_attr, input_field, direction)
 
     def CheckView(self, text, element_type="help"):
         """
@@ -313,8 +322,9 @@ class Webapp():
     def LogOff(self):
         """
         Logs out of the Protheus Webapp.
+        
         .. note::
-            .Do not use this method in any routine. Use on home screen
+            Do not use this method in any routine. Use on home screen.
 
         Usage:
 
@@ -416,17 +426,19 @@ class Webapp():
     def F3(self, field, name_attr=False,send_key=False):
         """
         Do the standard query(F3)
-        this method
-        1.Search the field
-        2.Search icon "lookup"
-        3.Click()
+        
+        this method:
+
+            1.Search the field
+            2.Search icon "lookup"
+            3.Click()
 
         :param term: The term that must be searched.
         :type  term: str
-        :param name_attr: True: searchs element by name
+        :param name_attr: True: searchs element by name.
         :type  name_attr: bool
-        :param send_key: True: try open standard search field send key F3
-        :type bool
+        :param send_key: True: try open standard search field send key F3.
+        :type send_key: bool
 
         Usage:
 
@@ -444,6 +456,7 @@ class Webapp():
     def SetupTSS(self, initial_program="", environment=""):
         """
         Prepare the Protheus Webapp TSS for the test case, filling the needed information to access the environment.
+
         .. note::
             This method use the user and password from config.json.
 
@@ -548,7 +561,7 @@ class Webapp():
         Fills the path screen with the desired path 
         
         .. warning::
-        Necessary informed the button name or the program will select the current button name.
+            Necessary informed the button name or the program will select the current button name.
 
         :param value: Path to be inputted.
         :type value: str
@@ -563,19 +576,25 @@ class Webapp():
         """
         self.__webapp.SetFilePath(value, button)
 
-    def SetFocus(self, field, grid_cell=False, row_number=1):
+    def SetFocus(self, field, grid_cell=False, row_number=1, position=1):
         """
         Sets the current focus on the desired field.
 
         :param field: The field that must receive the focus.
         :type field: str
+        :param grid_cell: Indicates if the element that deserve focus is on a grid.
+        :type grid_cell: bool
+        :param row_number: Number of row in case of multiples rows.
+        :type row_number: int
+        :param position: Position which element is located. - **Default:** 1
+        :type position: int
 
         Usage:
 
         >>> # Calling the method:
         >>> oHelper.SetFocus("A1_COD")
         """
-        self.__webapp.SetFocus(field,grid_cell,row_number)
+        self.__webapp.SetFocus(field, grid_cell, row_number, position)
 
     def SetKey(self, key, grid=False, grid_number=1,additional_key="", wait_show = "", step = 3): 
         """
@@ -1005,7 +1024,7 @@ class Webapp():
         
         return self.__webapp.ClickListBox(text)
 
-    def ClickImage(self, img_name):
+    def ClickImage(self, img_name, double_click=False):
         """
         Clicks in an Image button. They must be used only in case that 'ClickIcon' doesn't  support. 
         :param img_name: Image to be clicked.
@@ -1013,10 +1032,11 @@ class Webapp():
 
         Usage:
 
-        >>> # Call the method:  
-        >>> oHelper.ClickImage("img_name")
+        >>> # Call the method:
+        >>> oHelper.ClickImage("img_name")  
+        >>> oHelper.ClickImage("img_name",double_click=True)
         """
-        self.__webapp.ClickImage(img_name)
+        self.__webapp.ClickImage(img_name,double_click)
 
     def ProgramScreen(self, initial_program=""):
         """
